@@ -35,7 +35,6 @@ __email__ = "shyuep@gmail.com"
 __status__ = "Production"
 __date__ = "May 16, 2011"
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -217,8 +216,7 @@ class TransformedPDEntry(PDEntry):
 
     def __repr__(self):
         output = ["TransformedPDEntry {}".format(self.composition),
-                  " with original composition {}"
-                      .format(self.original_entry.composition),
+                  " with original composition {}".format(self.original_entry.composition),
                   ", E = {:.4f}".format(self.original_entry.energy)]
         return "".join(output)
 
@@ -317,14 +315,12 @@ class PhaseDiagram(MSONable):
         elements = list(elements)
         dim = len(elements)
 
-        get_reduced_comp = lambda e: e.composition.reduced_composition
-
-        entries = sorted(entries, key=get_reduced_comp)
+        entries = sorted(entries, key=lambda e: e.composition.reduced_composition)
 
         el_refs = {}
         min_entries = []
         all_entries = []
-        for c, g in itertools.groupby(entries, key=get_reduced_comp):
+        for c, g in itertools.groupby(entries, key=lambda e: e.composition.reduced_composition):
             g = list(g)
             min_entry = min(g, key=lambda e: e.energy_per_atom)
             if c.is_element:
@@ -603,7 +599,7 @@ class PhaseDiagram(MSONable):
         return self._get_facet_chempots(facet)
 
     def get_all_chempots(self, comp):
-        #note the top part takes from format of _get_facet_and_simplex,
+        # note the top part takes from format of _get_facet_and_simplex,
         #   but wants to return all facets rather than the first one that meets this criteria
         c = self.pd_coords(comp)
         allfacets = []
@@ -730,7 +726,6 @@ class PhaseDiagram(MSONable):
             'reaction': Reaction Object], ...]
         """
         element = get_el_sp(element)
-        element = Element(element.symbol)
 
         if element not in self.elements:
             raise ValueError("get_transition_chempots can only be called with"
@@ -834,7 +829,7 @@ class PhaseDiagram(MSONable):
             [e for e in self.elements if e != dep_elt])
 
         for e in self.elements:
-            if not e in target_comp.elements:
+            if e not in target_comp.elements:
                 target_comp = target_comp + Composition({e: 0.0})
         coeff = [-target_comp[e] for e in self.elements if e != dep_elt]
         for e in chempot_ranges.keys():
@@ -849,8 +844,7 @@ class PhaseDiagram(MSONable):
                         res = {}
                         for i in range(len(elts)):
                             res[elts[i]] = v[i] + muref[i]
-                        res[dep_elt] = (np.dot(v + muref, coeff) + ef) / \
-                                       target_comp[dep_elt]
+                        res[dep_elt] = (np.dot(v + muref, coeff) + ef) / target_comp[dep_elt]
                         already_in = False
                         for di in all_coords:
                             dict_equals = True
@@ -887,7 +881,7 @@ class PhaseDiagram(MSONable):
         chempot_ranges = self.get_chempot_range_map(
             [e for e in self.elements if e != open_elt])
         for e in self.elements:
-            if not e in target_comp.elements:
+            if e not in target_comp.elements:
                 target_comp = target_comp + Composition({e: 0.0})
         coeff = [-target_comp[e] for e in self.elements if e != open_elt]
         max_open = -float('inf')
@@ -903,15 +897,11 @@ class PhaseDiagram(MSONable):
                 for s in chempot_ranges[e]:
                     for v in s._coords:
                         all_coords.append(v)
-                        if (np.dot(v + muref, coeff) + ef) / target_comp[
-                                open_elt] > max_open:
-                            max_open = (np.dot(v + muref, coeff) + ef) / \
-                                       target_comp[open_elt]
+                        if (np.dot(v + muref, coeff) + ef) / target_comp[open_elt] > max_open:
+                            max_open = (np.dot(v + muref, coeff) + ef) / target_comp[open_elt]
                             max_mus = v
-                        if (np.dot(v + muref, coeff) + ef) / target_comp[
-                                open_elt] < min_open:
-                            min_open = (np.dot(v + muref, coeff) + ef) / \
-                                       target_comp[open_elt]
+                        if (np.dot(v + muref, coeff) + ef) / target_comp[open_elt] < min_open:
+                            min_open = (np.dot(v + muref, coeff) + ef) / target_comp[open_elt]
                             min_mus = v
         elts = [e for e in self.elements if e != open_elt]
         res = {}
@@ -1148,7 +1138,8 @@ class ReactionDiagram:
         rxn_entries = []
         done = []
 
-        fmt = lambda fl: float_fmt % fl
+        def fmt(fl):
+            return float_fmt % fl
 
         for facet in pd.facets:
             for face in itertools.combinations(facet, len(facet) - 1):
@@ -1222,9 +1213,9 @@ class ReactionDiagram:
         self.entry2 = entry2
         self.rxn_entries = rxn_entries
         self.labels = collections.OrderedDict()
-        for i, e in enumerate(rxn_entries): 
+        for i, e in enumerate(rxn_entries):
             self.labels[str(i + 1)] = e.attribute
-            e.name = str(i + 1) 
+            e.name = str(i + 1)
         self.all_entries = all_entries
         self.pd = pd
 
@@ -1246,7 +1237,7 @@ class ReactionDiagram:
             self.rxn_entries + [entry1, entry2],
             [Composition(entry1.composition.reduced_formula),
              Composition(entry2.composition.reduced_formula)],
-            normalize_terminal_compositions=False) 
+            normalize_terminal_compositions=False)
         return cpd
 
 
@@ -1422,7 +1413,7 @@ class PDPlotter:
         element_energy = evolution[0]['chempot']
         for i, d in enumerate(evolution):
             v = -(d["chempot"] - element_energy)
-            print ("index= %s, -\u0394\u03BC=%.4f(eV)," % (i, v), d["reaction"])
+            print("index= %s, -\u0394\u03BC=%.4f(eV)," % (i, v), d["reaction"])
             if i != 0:
                 plt.plot([x2, x2], [y1, d["evolution"] / num_atoms],
                          'k', linewidth=2.5)
@@ -1488,7 +1479,7 @@ class PDPlotter:
                 #  ICSD or from the MP) one.
                 for x, y in labels.keys():
                     if labels[(x, y)].attribute is None or \
-                                    labels[(x, y)].attribute == "existing":
+                            labels[(x, y)].attribute == "existing":
                         plt.plot(x, y, "ko", **self.plotkwargs)
                     else:
                         plt.plot(x, y, "k*", **self.plotkwargs)
@@ -1519,7 +1510,7 @@ class PDPlotter:
             if process_attributes:
                 for x, y in labels.keys():
                     if labels[(x, y)].attribute is None or \
-                                    labels[(x, y)].attribute == "existing":
+                            labels[(x, y)].attribute == "existing":
                         plt.plot(x, y, "o", markerfacecolor=vals_stable[ii],
                                  markersize=12)
                     else:
@@ -1732,9 +1723,7 @@ class PDPlotter:
             coords = []
             contain_zero = any([comp.get_atomic_fraction(el) == 0
                                 for el in elements])
-            is_boundary = (not contain_zero) and \
-                          sum([comp.get_atomic_fraction(el) for el in
-                               elements]) == 1
+            is_boundary = (not contain_zero) and sum([comp.get_atomic_fraction(el) for el in elements]) == 1
             for line in lines:
                 (x, y) = line.coords.transpose()
                 plt.plot(x, y, "k-")
@@ -1939,8 +1928,7 @@ def order_phase_diagram(lines, stable_entries, unstable_entries, ordering):
             yup = coord[1]
             nameup = stable_entries[coord].name
 
-    if (not nameup in ordering) or (not nameright in ordering) or \
-            (not nameleft in ordering):
+    if (nameup not in ordering) or (nameright not in ordering) or (nameleft not in ordering):
         raise ValueError(
             'Error in ordering_phase_diagram : \n"{up}", "{left}" and "{'
             'right}"'
@@ -1971,10 +1959,8 @@ def order_phase_diagram(lines, stable_entries, unstable_entries, ordering):
                 newx = np.zeros_like(x)
                 newy = np.zeros_like(y)
                 for ii, xx in enumerate(x):
-                    newx[ii] = c120 * (xx - cc[0]) - s120 * (y[ii] - cc[1]) + \
-                               cc[0]
-                    newy[ii] = s120 * (xx - cc[0]) + c120 * (y[ii] - cc[1]) + \
-                               cc[1]
+                    newx[ii] = c120 * (xx - cc[0]) - s120 * (y[ii] - cc[1]) + cc[0]
+                    newy[ii] = s120 * (xx - cc[0]) + c120 * (y[ii] - cc[1]) + cc[1]
                 newlines.append([newx, newy])
             newstable_entries = {
                 (c120 * (c[0] - cc[0]) - s120 * (c[1] - cc[1]) + cc[0],
@@ -2013,10 +1999,8 @@ def order_phase_diagram(lines, stable_entries, unstable_entries, ordering):
                 newx = np.zeros_like(x)
                 newy = np.zeros_like(y)
                 for ii, xx in enumerate(x):
-                    newx[ii] = c240 * (xx - cc[0]) - s240 * (y[ii] - cc[1]) + \
-                               cc[0]
-                    newy[ii] = s240 * (xx - cc[0]) + c240 * (y[ii] - cc[1]) + \
-                               cc[1]
+                    newx[ii] = c240 * (xx - cc[0]) - s240 * (y[ii] - cc[1]) + cc[0]
+                    newy[ii] = s240 * (xx - cc[0]) + c240 * (y[ii] - cc[1]) + cc[1]
                 newlines.append([newx, newy])
             newstable_entries = {
                 (c240 * (c[0] - cc[0]) - s240 * (c[1] - cc[1]) + cc[0],
